import { React, useState } from "react"
import { Image } from "react-bootstrap"
import axios from 'axios';

import { toast, ToastContainer } from 'react-toastify';
import "react-toastify/dist/ReactToastify.css";

import shareImg from '@assets/images/share.png';
import retrieveImg from '@assets/images/retrieve.png'

import { getEndpointBaseURL } from "@services/environment";

import ShareSceneModal from "./share-scene-modal"
import RetrieveModalSuccess from "./retrieve-modal-success";
import RetrieveModalFail from "./retrieve-modal-fail";

import './share-project.scss'
import { isNumber } from "../../../../../utils/helper-functions";

const ShareProject = ({ currentView, retrieveSession }) => {
    const [showShareScene, setShowShareScene] = useState(false);
    const [showRetrieveModalFail, setShowRetrieveModalFail] = useState(false);
    const [showRetrieveModalSuccess, setShowRetrieveModalSuccess] = useState(false);
    const [retrieveIp, setRetrieveIp] = useState('')
    const [sessionsData, setSessionsData] = useState({})

    const getIPForRetrieveScene = async (inputData) => {
        try {
          const item = (await axios.get(getEndpointBaseURL() + 'retrieveScene/' + inputData)).data;
          if(item.data[0]?.session_data){
            return item.data[0]?.session_data;
          }else{
            toast.error(item.message, {
                position: "top-right",
                hideProgressBar: false,
                theme: "colored"
              });
            return item.data
          }
        } catch (error) {
            toast.error(error, {
                position: "top-right",
                hideProgressBar: false,
                theme: "colored"
              });
          console.log('Retrieve scene error', error)
        }
    }
    
    const isInputValid = async () => {
        const inputElm = document.getElementById('inputElem').value;
        if(isNumber(inputElm) && inputElm.length > 0){
            if(inputElm.length === 4) {
                setShowRetrieveModalFail(false);
                const res = await getIPForRetrieveScene(inputElm)
                if(Object.keys(res).length > 0) {
                    setRetrieveIp(res.ipaddress)
                    setShowRetrieveModalSuccess(true)
                    setShowRetrieveModalFail(false);
                    setSessionsData(res)
                }else{
                    setShowRetrieveModalFail(true);
                    setShowRetrieveModalSuccess(false)
                }
            }else{
                setShowRetrieveModalFail(true);
            }
        }
    }

    return(
        <>
        <ToastContainer />
            <div className="shareProject">
                <div>
                    <p>
                        When you share a project, you will receive a unique code
                        which can be used to retrieve the same project on a different
                        device. Once open, you will be able to make changes and send
                        the updated scene back for further collaboration.
                    </p>
                    <br />
                </div>
                <div role="button" className="share-scene-button cursor-style">
                    <Image src={shareImg} alt=""/>
                    <span onClick={() => { setShowShareScene(true); }}>
                        Share Scene
                    </span>
                </div>
                <br />
                <div>
                    <p>
                        To retrieve a shared project, enter the code displayed on the sender's device below:
                    </p>
                    <br />
                    <input type="number" id="inputElem" placeholder="0000" minLength={4} />
                </div>
                <br />
                <div role="button" className="share-scene-button cursor-style" onClick={isInputValid}>
                    <Image src={retrieveImg} alt="" />
                    <span>Retrieve Scene</span>
                </div>
                
            </div>
            {
                (showShareScene === true) &&
                <>
                    <ShareSceneModal
                        show={showShareScene}
                        onHide={() =>  setShowShareScene(false) }
                    />
                </>
            }
            {
                (showRetrieveModalSuccess === true) && (
                    <RetrieveModalSuccess
                        show={showRetrieveModalSuccess}
                        onHide={() => setShowRetrieveModalSuccess(false)}
                        ipAddress={retrieveIp}
                        currentView={currentView}
                        retrieveSession={()=> retrieveSession(sessionsData)}
                    />
                )
            }
            {
                (showRetrieveModalFail === true) &&
                (
                    <RetrieveModalFail
                        show={showRetrieveModalFail}
                        onHide={() => setShowRetrieveModalFail(false)}
                    />
                )
            }
        </>
        
    )
}

export default ShareProject