import LocalStorage from '@services/local-storage'

const initialState = {
  timestamp: null,
  data: null,
  sampleRoom: null,
  products: null,
  defaultProduct: null,
  loading: true,
  error: null,
};

function updateSavedItems(newItem, saved) {
  let products = saved;
  if(!products){
    return [newItem]
  }
  products = [newItem, ...products.filter(item => 'favourites' in item)];

  let uniqueIds = new Set();
      let filteredSaved = products.filter(item => {
        if (!uniqueIds.has(item.id)) {
          uniqueIds.add(item.id);
          return true;
        }
        return false;
      });

  return filteredSaved;
}

const updateLocalStorage = (timeStamp, updatedRoomDetails) => {
  const savedProjects = JSON.parse(localStorage.getItem('savedProjects')) || [];
  const updatedData = savedProjects.map(savedProject => {
    if (Object.keys(savedProject)[0] === timeStamp) {
      return {
        [timeStamp]: updatedRoomDetails,
      };
    }
    return savedProject;
  });

  const isTimeStampExists = updatedData.some(item => Object.keys(item)[0] === timeStamp);

  if (!isTimeStampExists) {
    updatedData.unshift({ [timeStamp]: updatedRoomDetails });
  }

  LocalStorage.set('savedProjects', updatedData);
};


const rootSavedProjectsReducer = (state = initialState, action) => {
  const [initKey] = Object.keys(action.payload || {});
  const [firstKey] = Object.keys(state.data || {});

  switch (action.type) {
    case 'SET_SAVED_PROJECT_OBJECT':
      updateLocalStorage(initKey, action.payload[initKey]);
      return {
        ...state,
        loading: true,
        data: action.payload,
        sampleRoom: action.payload[initKey]['sampleRoom'],
      };

    case 'UPDATE_SAVED_PROJECT_OBJECT':
      const selectedRoomDetails = state.data?.[firstKey] || {};
      const { products } = selectedRoomDetails;
      const updatedProducts = updateSavedItems(action.payload, products);
      const updatedRoomDetails = { ...selectedRoomDetails, products: updatedProducts };

      updateLocalStorage(firstKey, updatedRoomDetails);

      return {
        ...state,
        loading: false,
        data: {
          ...state.data,
          [firstKey]: { ...updatedRoomDetails },
        },
        defaultProduct: updatedProducts[0],
        products: updatedProducts,
        sampleRoom: selectedRoomDetails['sampleRoom'],
        timestamp: firstKey,
      };

    case 'CLEAR_SAVED_PROJECT_DATA':
      return initialState;

    default:
      return state;
  }
};

export default rootSavedProjectsReducer;
